%global debug_package %{nil}

# rpmbuild < 4.6 support
%if ! 0%{?__isa_bits}
%ifarch x86_64 ia64 ppc64 sparc64 s390x alpha ppc64le aarch64
%global __isa_bits 64
%else
%global __isa_bits 32
%endif
%endif

Name:          leveldbjni
Version:       1.8
Release:       %mkrel 14
Group:         Development/Java
Summary:       A Java Native Interface to LevelDB
License:       BSD
URL:           https://github.com/fusesource/leveldbjni/
Source0:       https://github.com/fusesource/leveldbjni/archive/%{name}-%{version}.tar.gz

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.maven.plugin-tools:maven-plugin-tools-javadoc)
BuildRequires: mvn(org.fusesource:fusesource-pom:pom:)
BuildRequires: mvn(org.fusesource.hawtjni:hawtjni-runtime)
BuildRequires: mvn(org.fusesource.hawtjni:maven-hawtjni-plugin)
BuildRequires: mvn(org.iq80.leveldb:leveldb-api)
# see https://bugzilla.redhat.com/show_bug.cgi?id=881608
BuildRequires: pkgconfig(leveldb) >= 1.7.0-4
BuildRequires: snappy-devel

%description
LevelDB JNI gives you a Java interface to the
LevelDB C++ library which is a fast key-value
storage library written at Google that provides
an ordered mapping from string keys to string
values.

%package javadoc
Summary:       Javadoc for %{name}
BuildArch:     noarch

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin :jxr-maven-plugin
%pom_remove_plugin :surefire-report-maven-plugin
# disable non linux module
%pom_remove_dep org.fusesource.%{name}:%{name}-osx %{name}-all
%pom_remove_dep org.fusesource.leveldbjni:leveldbjni-win32 %{name}-all
%pom_remove_dep org.fusesource.leveldbjni:leveldbjni-win64 %{name}-all

%pom_xpath_remove "pom:Private-Package" %{name}-all
%pom_xpath_remove "pom:Export-Package" %{name}-all
%pom_xpath_remove "pom:Import-Package" %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Import-Package>
 org.fusesource.hawtjni.runtime,
 org.iq80.leveldb*;version=${leveldb-api-version}
</Import-Package>' %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Export-Package>
 org.fusesource.leveldbjni*;version=${project.version}
</Export-Package>' %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" '
<Private-Package>
 org.fusesource.leveldbjni.internal*
</Private-Package>' %{name}-all

%pom_xpath_remove "pom:Bundle-NativeCode"  %{name}-all

%if %{__isa_bits} == 64

%pom_remove_dep org.fusesource.%{name}:%{name}-linux32 %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" "
<Bundle-NativeCode>
  META-INF/native/linux64/libleveldbjni.so;osname=Linux;processor=x86-64
</Bundle-NativeCode>" %{name}-all

%else

%pom_remove_dep org.fusesource.%{name}:%{name}-linux64 %{name}-all

%pom_xpath_inject "pom:plugin[pom:artifactId='maven-bundle-plugin']/pom:configuration/pom:instructions" "
<Bundle-NativeCode>
  META-INF/native/linux32/libleveldbjni.so;osname=Linux;processor=x86
</Bundle-NativeCode>" %{name}-all

%endif

rm -r %{name}/src/test/java/org/fusesource/%{name}/test/DBTest.java
cp -f /usr/lib/rpm/config.{sub,guess} /usr/share/automake-*/compile leveldbjni/src/main/native-package/autotools/

%build

%ifarch ppc64
export MAVEN_OPTS='-Xms1024m -Xmx2048m -XX:MaxPermSize=384m'
%endif
%mvn_file :%{name}-all %{name}-all
%mvn_file :%{name}-linux%{__isa_bits} %{name}-linux
export JAVA_HOME=%{_jvmdir}/java LEVELDB_HOME=%{_prefix} SNAPPY_HOME=%{_prefix}
%mvn_build -- -Plinux%{__isa_bits},all -Dleveldb=%{_prefix} -Dsnappy=%{_prefix}

%install
%mvn_install

%files  -f .mfiles
%doc changelog.md readme.md releasing.md
%license license.txt

%files javadoc -f .mfiles-javadoc
%license license.txt



%changelog
* Sun Jan 01 2017 akien <akien> 1.8-14.mga6
+ Revision: 1079428
- Rebuild for leveldb 1.19

* Thu May 05 2016 daviddavid <daviddavid> 1.8-13.mga6
+ Revision: 1009620
- add back previous fix to make it build

* Fri Apr 29 2016 daviddavid <daviddavid> 1.8-12.mga6
+ Revision: 1007666
- fix Missing class in leveldbjni-all.jar (rhbz#1326445)
- fix BR list (use mvn,pkgconfig()-like)
- introduce license macro
- update config.sub to support ppc64le
- set MAVEN_OPTS on ppc64 to work around java.lang.StackOverflowError
- Add a better 32/64 architecture detection

  + neoclust <neoclust>
    - Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.8-10.mga6
+ Revision: 978697
- First rebuild of the java stack

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Dec 28 2014 pterjan <pterjan> 1.8-1.mga5
+ Revision: 807020
- Make it build
- Fix BuildRequires
- Mageify
- imported package leveldbjni

